==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/connect/kotlin/outputs/GetUserHierarchyStructureHierarchyStructure.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.connect.kotlin.outputs

import kotlin.Suppress
import kotlin.collections.List

/**
 *
 * @property levelFives Details of level five. See below.
 * @property levelFours Details of level four. See below.
 * @property levelOnes Details of level one. See below.
 * @property levelThrees Details of level three. See below.
 * @property levelTwos Details of level two. See below.
 */
public data class GetUserHierarchyStructureHierarchyStructure(
    public val levelFives: List<GetUserHierarchyStructureHierarchyStructureLevelFife>,
    public val levelFours: List<GetUserHierarchyStructureHierarchyStructureLevelFour>,
    public val levelOnes: List<GetUserHierarchyStructureHierarchyStructureLevelOne>,
    public val levelThrees: List<GetUserHierarchyStructureHierarchyStructureLevelThree>,
    public val levelTwos: List<GetUserHierarchyStructureHierarchyStructureLevelTwo>,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.aws.connect.outputs.GetUserHierarchyStructureHierarchyStructure):
            GetUserHierarchyStructureHierarchyStructure = GetUserHierarchyStructureHierarchyStructure(
            levelFives = javaType.levelFives().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.connect.kotlin.outputs.GetUserHierarchyStructureHierarchyStructureLevelFife.Companion.toKotlin(args0)
                })
            }),
            levelFours = javaType.levelFours().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.connect.kotlin.outputs.GetUserHierarchyStructureHierarchyStructureLevelFour.Companion.toKotlin(args0)
                })
            }),
            levelOnes = javaType.levelOnes().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.connect.kotlin.outputs.GetUserHierarchyStructureHierarchyStructureLevelOne.Companion.toKotlin(args0)
                })
            }),
            levelThrees = javaType.levelThrees().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.connect.kotlin.outputs.GetUserHierarchyStructureHierarchyStructureLevelThree.Companion.toKotlin(args0)
                })
            }),
            levelTwos = javaType.levelTwos().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.connect.kotlin.outputs.GetUserHierarchyStructureHierarchyStructureLevelTwo.Companion.toKotlin(args0)
                })
            }),
        )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/connect/kotlin/outputs/GetUserHierarchyStructureHierarchyStructure.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.connect.kotlin.outputs

import kotlin.Suppress
import kotlin.collections.List

/**
 *
 * @property levelFives Details of level five. See below.
 * @property levelFours Details of level four. See below.
 * @property levelOnes Details of level one. See below.
 * @property levelThrees Details of level three. See below.
 * @property levelTwos Details of level two. See below.
 */
public data class GetUserHierarchyStructureHierarchyStructure(
    public val levelFives: List<GetUserHierarchyStructureHierarchyStructureLevelFife>,
    public val levelFours: List<GetUserHierarchyStructureHierarchyStructureLevelFour>,
    public val levelOnes: List<GetUserHierarchyStructureHierarchyStructureLevelOne>,
    public val levelThrees: List<GetUserHierarchyStructureHierarchyStructureLevelThree>,
    public val levelTwos: List<GetUserHierarchyStructureHierarchyStructureLevelTwo>,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.connect.outputs.GetUserHierarchyStructureHierarchyStructure): GetUserHierarchyStructureHierarchyStructure = GetUserHierarchyStructureHierarchyStructure(
            levelFives = javaType.levelFives().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.connect.kotlin.outputs.GetUserHierarchyStructureHierarchyStructureLevelFife.Companion.toKotlin(args0)
                })
            }),
            levelFours = javaType.levelFours().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.connect.kotlin.outputs.GetUserHierarchyStructureHierarchyStructureLevelFour.Companion.toKotlin(args0)
                })
            }),
            levelOnes = javaType.levelOnes().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.connect.kotlin.outputs.GetUserHierarchyStructureHierarchyStructureLevelOne.Companion.toKotlin(args0)
                })
            }),
            levelThrees = javaType.levelThrees().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.connect.kotlin.outputs.GetUserHierarchyStructureHierarchyStructureLevelThree.Companion.toKotlin(args0)
                })
            }),
            levelTwos = javaType.levelTwos().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.connect.kotlin.outputs.GetUserHierarchyStructureHierarchyStructureLevelTwo.Companion.toKotlin(args0)
                })
            }),
        )
    }
}
